@@ -214,7 +214,7 @@ fn url_from_file(file: &gio::File) -> Result<Url, LoadingError> {
 ///
 /// You can create this from one of the `read` methods in
 /// [`Loader`].
-pub struct SvgHandle(Handle);
+pub struct SvgHandle(pub(crate) Handle);
 
 impl SvgHandle {
     /// Checks if the SVG has an element with the specified `id`.
@@ -243,8 +243,8 @@ impl SvgHandle {
 
 /// Can render an `SvgHandle` to a Cairo context.
 pub struct CairoRenderer<'a> {
-    handle: &'a SvgHandle,
-    dpi: Dpi,
+    pub(crate) handle: &'a SvgHandle,
+    pub(crate) dpi: Dpi,
     user_language: UserLanguage,
     is_testing: bool,
 }
@@ -365,7 +365,21 @@ impl<'a> CairoRenderer<'a> {
     /// kind require more information to be resolved to pixels; for example, the calling
     /// application can use a viewport size to scale percentage-based dimensions.
     pub fn intrinsic_size_in_pixels(&self) -> Option<(f64, f64)> {
-        self.handle.0.get_intrinsic_size_in_pixels(self.dpi)
+        let dim = self.intrinsic_dimensions();
+
+        // missing width/height default to "auto", which compute to "100%"
+        let width = dim
+            .width
+            .unwrap_or_else(|| Length::new(1.0, LengthUnit::Percent));
+        let height = dim
+            .height
+            .unwrap_or_else(|| Length::new(1.0, LengthUnit::Percent));
+
+        if width.unit == LengthUnit::Percent || height.unit == LengthUnit::Percent {
+            return None;
+        }
+
+        Some(self.handle.0.width_height_to_user(self.dpi))
     }
 
     /// Renders the whole SVG document fitted to a viewport
@@ -529,10 +543,7 @@ impl<'a> CairoRenderer<'a> {
     }
 
     /// Turns on test mode.  Do not use this function; it is for librsvg's test suite only.
-    pub fn test_mode(self) -> Self {
-        CairoRenderer {
-            is_testing: true,
-            ..self
-        }
+    pub fn test_mode(self, is_testing: bool) -> Self {
+        CairoRenderer { is_testing, ..self }
     }
 }
