@@ -108,28 +108,21 @@ impl Handle {
         }
     }
 
-    /// If the intrinsic dimensions are in physical units, computes their pixel size, or
-    /// returns `None`.
+    /// Normalizes the svg's width/height properties with a 0-sized viewport
     ///
-    /// If any of the width/height are percentages, we cannot compute the size here.  Here
-    /// just normalize lengths with physical units, or units based on the font size.
-    pub fn get_intrinsic_size_in_pixels(&self, dpi: Dpi) -> Option<(f64, f64)> {
+    /// This assumes that if one of the properties is in percentage units, then
+    /// its corresponding value will not be used.  E.g. if width=100%, the caller
+    /// will ignore the resulting width value.
+    pub fn width_height_to_user(&self, dpi: Dpi) -> (f64, f64) {
         let dimensions = self.get_intrinsic_dimensions();
 
-        if dimensions.width.is_none() || dimensions.height.is_none() {
-            // If either of width/height don't exist, the spec says they should default to 100%,
-            // which is a percentage-based unit - which we can't resolve here.
-            return None;
-        }
-
-        let w = dimensions.width.unwrap();
-        let h = dimensions.height.unwrap();
-
-        use crate::length::LengthUnit::*;
-
-        if w.unit == Percent || h.unit == Percent {
-            return None;
-        }
+        // missing width/height default to "auto", which compute to "100%"
+        let width = dimensions
+            .width
+            .unwrap_or_else(|| ULength::new(1.0, LengthUnit::Percent));
+        let height = dimensions
+            .height
+            .unwrap_or_else(|| ULength::new(1.0, LengthUnit::Percent));
 
         let view_params = ViewParams::new(dpi, 0.0, 0.0);
         let root = self.document.root();
@@ -138,7 +131,7 @@ impl Handle {
 
         let params = NormalizeParams::new(values, &view_params);
 
-        Some((w.to_user(&params), h.to_user(&params)))
+        (width.to_user(&params), height.to_user(&params))
     }
 
     fn get_node_or_root(&self, id: Option<&str>) -> Result<Node, RenderingError> {
