@@ -50,7 +50,6 @@ macro_rules! impl_draw {
                 cascaded: &CascadedValues<'_>,
                 draw_ctx: &mut DrawingCtx,
                 clipping: bool,
-                //context: &CascadedValues<'_>.inner::FromNode,
             ) -> Result<BoundingBox, RenderingError> {
                 let values = cascaded.get();
                 let view_params = draw_ctx.get_view_params();
@@ -131,7 +130,7 @@ macro_rules! impl_draw {
 
                 let elt = node.borrow_element();
                 let stacking_ctx =
-                    StackingContext::new(acquired_nodes, &elt, elt.get_transform(), values);
+                    StackingContext::new(acquired_nodes, &elt, values.transform(), values);
 
                 draw_ctx.draw_shape(
                     &view_params,
@@ -407,8 +406,8 @@ impl BasicShape for Line {
 pub struct Rect {
     x: Length<Horizontal>,
     y: Length<Vertical>,
-    width: ULength<Horizontal>,
-    height: ULength<Vertical>,
+    width: LengthOrAuto<Horizontal>,
+    height: LengthOrAuto<Vertical>,
 
     // Radiuses for rounded corners
     rx: Option<Length<Horizontal>>,
@@ -440,8 +439,15 @@ impl BasicShape for Rect {
     fn make_shape(&self, params: &NormalizeParams) -> ShapeDef {
         let x = self.x.to_user(params);
         let y = self.y.to_user(params);
-        let w = self.width.to_user(params);
-        let h = self.height.to_user(params);
+
+        let w = match self.width {
+            LengthOrAuto::Length(l) => l.to_user(params),
+            LengthOrAuto::Auto => 0.0,
+        };
+        let h = match self.height {
+            LengthOrAuto::Length(l) => l.to_user(params),
+            LengthOrAuto::Auto => 0.0,
+        };
 
         let specified_rx = self.rx.map(|l| l.to_user(params));
         let specified_ry = self.ry.map(|l| l.to_user(params));
@@ -513,7 +519,6 @@ impl BasicShape for Rect {
             builder.line_to(x + w, y + h);
             builder.line_to(x, y + h);
             builder.line_to(x, y);
-            builder.close_path();
         } else {
             /* Hard case, rounded corners
              *
@@ -608,10 +613,10 @@ impl BasicShape for Rect {
                 top_x1,
                 top_y,
             );
-
-            builder.close_path();
         }
 
+        builder.close_path();
+
         ShapeDef::new(Rc::new(builder.into_path()), Markers::No)
     }
 }
