@@ -1,4 +1,5 @@
 use cairo;
+use libc;
 use librsvg::surface_utils::shared_surface::{SharedImageSurface, SurfaceType};
 use librsvg::{CairoRenderer, RenderingError};
 
@@ -219,3 +220,48 @@ fn set_stylesheet() {
         .compare(&output_surf)
         .evaluate(&output_surf, "set_stylesheet");
 }
+
+fn has_current_point(cr: &cairo::Context) -> bool {
+    // https://github.com/gtk-rs/gtk-rs-core/issues/335
+    //
+    // cairo-rs-sys incorrectly declares cairo_bool_t as a repr(C)
+    // struct; it needs to be repr(transparent).  So, we'll call
+    // has_current_point by hand.
+
+    extern "C" {
+        fn cairo_has_current_point(cr: *mut cairo::ffi::cairo_t) -> libc::c_int;
+    }
+
+    unsafe { cairo_has_current_point(cr.to_raw_none()) != 0 }
+}
+
+// https://gitlab.gnome.org/GNOME/librsvg/-/issues/799
+#[test]
+fn text_doesnt_leave_points_in_current_path() {
+    let svg = load_svg(
+        br##"<?xml version="1.0" encoding="UTF-8"?>
+<svg xmlns="http://www.w3.org/2000/svg" width="100" height="100">
+  <text>Hello world!</text>
+</svg>
+"##,
+    )
+    .unwrap();
+
+    let renderer = CairoRenderer::new(&svg);
+
+    let output = cairo::ImageSurface::create(cairo::Format::ARgb32, 100, 100).unwrap();
+    let cr = cairo::Context::new(&output).unwrap();
+
+    assert!(!has_current_point(&cr));
+
+    let viewport = cairo::Rectangle {
+        x: 0.0,
+        y: 0.0,
+        width: 100.0,
+        height: 100.0,
+    };
+
+    renderer.render_document(&cr, &viewport).unwrap();
+
+    assert!(!has_current_point(&cr));
+}
